@@ -26,6 +26,12 @@ isRMariaDB <- function(conn) {
   inherits(conn, "MariaDBConnection")
 }
 
+isMariaDB <- function(conn) {
+  # RMariaDB uses MySQLConnection for MySQL for 1.3+
+  # TODO add detection for other adapters
+  inherits(conn, "MariaDBConnection") && !is(conn, "MySQLConnection")
+}
+
 isSQLite <- function(conn) {
   inherits(conn, "SQLiteConnection")
 }
@@ -41,3 +47,15 @@ isSQLServer <- function(conn) {
 isODBC <- function(conn) {
   !is.null(attr(conn, "info")$odbc.version)
 }
+
+isDuckDB <- function(conn) {
+  inherits(conn, "duckdb_connection")
+}
+
+isMac <- function() {
+  Sys.info()["sysname"] == "Darwin"
+}
+
+returningSupported <- function(conn) {
+  isPostgres(conn) || isMariaDB(conn) || isSQLite(conn) || isSQLServer(conn) || isDuckDB(conn)
+}
